@@ -24,10 +24,10 @@ from catkin_create_pkg import main
 class CreatePkgTest(unittest.TestCase):
 
     def test_create_package_template(self):
-        template = PackageTemplate._create_package_template('fooPackage')
-        self.assertEqual('fooPackage', template.name)
+        template = PackageTemplate._create_package_template('foopackage')
+        self.assertEqual('foopackage', template.name)
         self.assertEqual('0.0.0', template.version)
-        self.assertEqual('The fooPackage package', template.description)
+        self.assertEqual('The foopackage package', template.description)
         self.assertEqual([], template.catkin_deps)
         self.assertEqual([], template.authors)
         self.assertEqual(1, len(template.maintainers))
@@ -35,14 +35,14 @@ class CreatePkgTest(unittest.TestCase):
         self.assertEqual([], template.urls)
         # with args
         template = PackageTemplate._create_package_template(
-            'fooPackage',
+            'foopackage',
             description='foo_desc',
             licenses=['a', 'b'],
             maintainer_names=['John Doe', 'Jim Daniels'],
             author_names=['Harry Smith'],
             version='1.2.3',
             catkin_deps=['foobar', 'baz'])
-        self.assertEqual('fooPackage', template.name)
+        self.assertEqual('foopackage', template.name)
         self.assertEqual('1.2.3', template.version)
         self.assertEqual('foo_desc', template.description)
         self.assertEqual(['baz', 'foobar'], template.catkin_deps)
